@@ -1,6 +1,3 @@
-# (c) 2012-2013 Continuum Analytics, Inc. / http://continuum.io
-# All Rights Reserved
-#
 # conda is distributed under the terms of the BSD 3-clause license.
 # Consult LICENSE.txt or http://opensource.org/licenses/BSD-3-Clause.
 
@@ -15,13 +12,15 @@ globally (such as downloading packages).
 
 We don't raise an error if the lock is named with the current PID
 """
-from __future__ import absolute_import, division, print_function
+from __future__ import absolute_import, division, print_function, unicode_literals
+
+from glob import glob
 import logging
 import os
+from os.path import abspath, basename, dirname, isdir, join
 import time
-from glob import glob
-from os.path import abspath, isdir, dirname, basename, join
-from .compat import range
+
+from .common.compat import range
 from .exceptions import LockError
 
 LOCK_EXTENSION = 'conda_lock'
@@ -35,8 +34,8 @@ If you are sure that conda is not running, remove it and try again.
 You can also use: $ conda clean --lock
 """
 
-stdoutlog = logging.getLogger('stdoutlog')
 log = logging.getLogger(__name__)
+stdoutlog = logging.getLogger('conda.stdoutlog')
 
 def touch(file_name, times=None):
     """ Touch function like touch in Unix shell
@@ -94,11 +93,12 @@ class FileLock(object):
         raise LockError(LOCKSTR.format(last_glob_match))
 
     def __exit__(self, exc_type, exc_value, traceback):
-        from conda.common.disk import rm_rf
+        from .gateways.disk.delete import rm_rf
         rm_rf(self.lock_file_path)
 
 
-class DirectoryLock(FileLock):
+# lgtm alert ignore because this lock functionality is unused and will soon be replaced
+class DirectoryLock(FileLock):  # lgtm [py/missing-call-to-init]
     """Lock a directory with the lock file sitting *within* the directory being locked.
 
     Useful when, for example, locking the root prefix at ``/conda``, and ``/`` is not writable.
