@@ -3,10 +3,11 @@ import os
 import sys
 import textwrap
 
-from conda.cli import common, install as cli_install
+from conda._vendor.auxlib.path import expand
+from conda.cli import install as cli_install
+from conda.cli.conda_argparse import add_parser_json, add_parser_prefix
 from conda.misc import touch_nonadmin
-# for conda env
-from conda_env.cli.common import get_prefix
+from .common import get_prefix
 from .. import exceptions, specs as install_specs
 from ..exceptions import CondaEnvException
 from ..installers.base import InvalidInstaller, get_installer
@@ -33,7 +34,7 @@ def configure_parser(sub_parsers):
         help=description,
         epilog=example,
     )
-    common.add_parser_prefix(p)
+    add_parser_prefix(p)
     p.add_argument(
         '-f', '--file',
         action='store',
@@ -58,15 +59,15 @@ def configure_parser(sub_parsers):
         default=None,
         nargs='?'
     )
-    common.add_parser_json(p)
-    p.set_defaults(func=execute)
+    add_parser_json(p)
+    p.set_defaults(func='.main_update.execute')
 
 
 def execute(args, parser):
     name = args.remote_definition or args.name
 
     try:
-        spec = install_specs.detect(name=name, filename=args.file,
+        spec = install_specs.detect(name=name, filename=expand(args.file),
                                     directory=os.getcwd())
         env = spec.environment
     except exceptions.SpecNotFound:
@@ -100,11 +101,15 @@ def execute(args, parser):
     # common.ensure_override_channels_requires_channel(args)
     # channel_urls = args.channel or ()
 
-    for installer_type, specs in env.dependencies.items():
+    # create installers before running any of them
+    # to avoid failure to import after the file being deleted
+    # e.g. due to conda_env being upgraded or Python version switched.
+    installers = {}
+
+    for installer_type in env.dependencies:
         try:
-            installer = get_installer(installer_type)
-            installer.install(prefix, specs, args, env, prune=args.prune)
-        except InvalidInstaller:
+            installers[installer_type] = get_installer(installer_type)
+        except InvalidInstaller as e:
             sys.stderr.write(textwrap.dedent("""
                 Unable to install package for {0}.
 
@@ -116,6 +121,9 @@ def execute(args, parser):
             )
             return -1
 
+    for installer_type, specs in env.dependencies.items():
+        installer = installers[installer_type]
+        installer.install(prefix, specs, args, env)
+
     touch_nonadmin(prefix)
-    if not args.json:
-        print(cli_install.print_activate(args.name if args.name else prefix))
+    cli_install.print_activate(args.name if args.name else prefix)
